pub type RecordedCall = (String, String, Option<String>);
One recorded host call: the module, the operation, and the first argument when it was a string, which for reviews is the request identifier.
reviews